@@ -35,8 +35,8 @@ parameters_constructor <- function(
   ...
 ) {
 
-  na_cols <- data %>%
-    dplyr::select({{ id }}, {{ atc }}, {{ timing }}, {{ base_clustering }}) %>%
+  na_cols <- data |>
+    dplyr::select({{ id }}, {{ atc }}, {{ timing }}, {{ base_clustering }}) |>
     dplyr::summarise(dplyr::across(dplyr::everything(), ~ any(is.na(.))))
 
   if (any(na_cols)) {
@@ -66,13 +66,13 @@ parameters_constructor <- function(
   }
 
   if (! missing(base_clustering)) {
-    test <- data %>%
-      dplyr::group_by({{ id }}) %>%
+    test <- data |>
+      dplyr::group_by({{ id }}) |>
       dplyr::summarise(
         n = dplyr::n_distinct({{ base_clustering }}),
         .groups = "drop"
-      ) %>%
-      dplyr::summarise(test = any(.data$n > 1), .groups = "drop") %>%
+      ) |>
+      dplyr::summarise(test = any(.data$n > 1), .groups = "drop") |>
       dplyr::pull(.data$test)
     if (test) {
       stop(
@@ -98,11 +98,11 @@ parameters_constructor <- function(
           gamma = gamma,
           p = p,
           theta_list = if (is.list(theta)) theta else list(theta)
-        ) %>%
+        ) |>
           dplyr::mutate(
             theta = as.character(theta_list),
             clustering = paste0("cluster_", dplyr::row_number())
-          ) %>%
+          ) |>
           dplyr::relocate("clustering")
       },
       error = function(cond) {
@@ -114,7 +114,9 @@ parameters_constructor <- function(
         )
         stop(cond)
       },
-      finally = {df}
+      finally = {
+        df
+      }
     )
   )
 }
@@ -132,7 +134,7 @@ parameters_constructor <- function(
 #' @noRd
 key_constructor <- function(data, id, base_clustering, atc, timing) {
 
-  key <- data %>%
+  key <- data |>
     dplyr::select(
       ".internal_character_id",
       {{ id }},
@@ -144,15 +146,15 @@ key_constructor <- function(data, id, base_clustering, atc, timing) {
 
   #   ===   Unique ATC codes   =================================================
 
-  if (data %>% dplyr::select({{ atc }}) %>% ncol() != 0) {
+  if (data |> dplyr::select({{ atc }}) |> ncol() != 0) {
 
-    unique_atc <- data %>%
-      dplyr::select({{ atc }}) %>%
-      dplyr::distinct() %>%
-      dplyr::mutate(unique_atc_key = dplyr::row_number()) %>%
+    unique_atc <- data |>
+      dplyr::select({{ atc }}) |>
+      dplyr::distinct() |>
+      dplyr::mutate(unique_atc_key = dplyr::row_number()) |>
       dplyr::relocate("unique_atc_key")
 
-    key <- key %>%
+    key <- key |>
       dplyr::left_join(unique_atc, by = names(unique_atc)[-1])
 
     out <- list(unique_atc = unique_atc)
@@ -166,15 +168,15 @@ key_constructor <- function(data, id, base_clustering, atc, timing) {
 
   #   ===   Unique Timing codes   ==============================================
 
-  if (data %>% dplyr::select({{ timing }}) %>% ncol() != 0) {
+  if (data |> dplyr::select({{ timing }}) |> ncol() != 0) {
 
-    unique_timing <- data %>%
-      dplyr::select({{ timing }}) %>%
-      dplyr::distinct() %>%
-      dplyr::mutate(unique_timing_key = dplyr::row_number()) %>%
+    unique_timing <- data |>
+      dplyr::select({{ timing }}) |>
+      dplyr::distinct() |>
+      dplyr::mutate(unique_timing_key = dplyr::row_number()) |>
       dplyr::relocate("unique_timing_key")
 
-    key <- key %>%
+    key <- key |>
       dplyr::left_join(unique_timing, by = names(unique_timing)[-1])
 
     out <- c(out, list(unique_timing = unique_timing))
@@ -183,13 +185,13 @@ key_constructor <- function(data, id, base_clustering, atc, timing) {
 
   #   ===   Unique Exposure   ==================================================
 
-  unique_exposure <- key %>%
-    dplyr::select(dplyr::any_of(c("unique_atc_key", "unique_timing_key"))) %>%
-    dplyr::distinct() %>%
-    dplyr::mutate(unique_exposure_key = dplyr::row_number()) %>%
+  unique_exposure <- key |>
+    dplyr::select(dplyr::any_of(c("unique_atc_key", "unique_timing_key"))) |>
+    dplyr::distinct() |>
+    dplyr::mutate(unique_exposure_key = dplyr::row_number()) |>
     dplyr::relocate("unique_exposure_key")
 
-  key <- key %>%
+  key <- key |>
     dplyr::left_join(unique_exposure, by = names(unique_exposure)[-1])
 
   out <- c(out, list(unique_exposure = unique_exposure))
@@ -198,25 +200,25 @@ key_constructor <- function(data, id, base_clustering, atc, timing) {
   #   ===  Unique patterns   ===================================================
 
 
-  nest_key <- key %>%
+  nest_key <- key |>
     tidyr::nest(pattern = unique(unlist(lapply(out, names))))
 
-  unique_patterns <- nest_key %>%
-    dplyr::select("pattern") %>%
-    dplyr::distinct() %>%
+  unique_patterns <- nest_key |>
+    dplyr::select("pattern") |>
+    dplyr::distinct() |>
     dplyr::mutate(unique_pattern_key = dplyr::row_number(),
-                  n_unique_exposures = sapply(.data$pattern, nrow)) %>%
+                  n_unique_exposures = sapply(.data$pattern, nrow)) |>
     dplyr::relocate("unique_pattern_key", "n_unique_exposures")
 
-  key <- nest_key %>%
-    dplyr::left_join(unique_patterns, by = "pattern") %>%
+  key <- nest_key |>
+    dplyr::left_join(unique_patterns, by = "pattern") |>
     tidyr::unnest("pattern")
 
   out <- c(out, list(unique_patterns = unique_patterns))
 
-  if (data %>% dplyr::select({{ base_clustering }}) %>% ncol() != 0) {
-    base_clu <- key %>%
-      dplyr::select({{ base_clustering }}, "unique_pattern_key") %>%
+  if (data |> dplyr::select({{ base_clustering }}) |> ncol() != 0) {
+    base_clu <- key |>
+      dplyr::select({{ base_clustering }}, "unique_pattern_key") |>
       dplyr::distinct()
     out <- c(out, list(base_clustering = base_clu))
   }
@@ -230,18 +232,18 @@ key_constructor <- function(data, id, base_clustering, atc, timing) {
 
   #   ===   Construct Reduced Keys   ===========================================
 
-  rms <- key %>%
+  rms <- key |>
     dplyr::select(
       ".internal_character_id",
       {{ id }},
       {{ base_clustering }},
       {{ atc }},
       {{ timing }}
-    ) %>%
+    ) |>
     names()
 
-  reduced_key <- key %>%
-    dplyr::select(-dplyr::any_of(rms)) %>%
+  reduced_key <- key |>
+    dplyr::select(-dplyr::any_of(rms)) |>
     dplyr::distinct()
 
   #   ===   Return Results   ===================================================
@@ -309,8 +311,8 @@ lookup_constructor <- function(keys, parameters) {
 #' @noRd
 atc_metric_lookup_constructor <- function(unique_atc) {
 
-  atc_codes <- unique_atc %>%
-    dplyr::select(-"unique_atc_key") %>%
+  atc_codes <- unique_atc |>
+    dplyr::select(-"unique_atc_key") |>
     dplyr::pull(1)
 
   atc_levels <- data.frame(
@@ -327,7 +329,7 @@ atc_metric_lookup_constructor <- function(unique_atc) {
     })
   })
 
-  atc_names <- unique_atc %>% dplyr::pull(.data$unique_atc_key)
+  atc_names <- unique_atc |> dplyr::pull(.data$unique_atc_key)
   dimnames(res) <- list(atc_names, atc_names)
 
   return(res + 1)
@@ -351,7 +353,7 @@ normalizing_lookup_constructor <- function(
   summation_methods = "double_sum"
 ) {
 
-  int_exposure_in_pattern <- unique_patterns %>%
+  int_exposure_in_pattern <- unique_patterns |>
     dplyr::pull(.data$n_unique_exposures, name = .data$unique_pattern_key)
 
   numeric_exposure_in_pattern <- as.numeric(int_exposure_in_pattern)
@@ -397,7 +399,7 @@ normalizing_lookup_constructor <- function(
 #' @param unique_timing data frame
 #' @param ps the unique 'p's chosen
 #' @noRd
-timing_metric_lookup_constructor <- function(unique_timing, ps) {
+timing_metric_lookup_constructor <- function(unique_timing, ps = 1L) {
   res <- lapply(
     ps,
     function(p) {
@@ -519,16 +521,16 @@ distance_matrix_constructor <- function(
 ) {
 
   if ((!is.null(old_patterns)) && (!is.null(new_patterns))) {
-    rows <- keys$reduced_key %>%
-      dplyr::filter(.data$unique_pattern_key %in% old_patterns)
-    cols <- keys$reduced_key %>%
+    rows <- keys$reduced_key |>
       dplyr::filter(.data$unique_pattern_key %in% new_patterns)
+    cols <- keys$reduced_key |>
+      dplyr::filter(.data$unique_pattern_key %in% old_patterns)
     calc <- "full"
 
     if (method["alpha"] != 0) {
-      normalizer <- cur_tables$normalizing_factor[
-        which(keys$unique_patterns$unique_pattern_key %in% old_patterns),
-        which(keys$unique_patterns$unique_pattern_key %in% new_patterns)
+      normalizer <- cur_tables$normalizing_factor[ # This is now row-col flipped -- does the cur_table need flipping?? normalizing factor is not symmetric!!!
+        which(keys$unique_patterns$unique_pattern_key %in% new_patterns),
+        which(keys$unique_patterns$unique_pattern_key %in% old_patterns)
       ]
     }
   } else {
@@ -546,31 +548,19 @@ distance_matrix_constructor <- function(
 
     # atc metric by pattern
     if (all(method$theta != 0)) {
-      inner_terms_atc <- apply(
-        rows,
-        1,
-        function(r) {
-          cur_tables$atc_table[
-            r["unique_atc_key"],
-            cols$unique_atc_key
-          ]
-        }
-      ) + 1
+      inner_terms_atc <- cur_tables$atc_table[
+        rows$unique_atc_key,
+        cols$unique_atc_key
+      ] + 1
       inner_terms <- inner_terms * inner_terms_atc
     }
 
     # multiplied with timing metric by pattern
     if (method$gamma != 0) {
-      inner_terms_timing <- apply(
-        rows,
-        1,
-        function(r) {
-          cur_tables$timing_table[
-            r["unique_timing_key"],
-            cols$unique_timing_key
-          ]
-        }
-      ) + 1
+      inner_terms_timing <- cur_tables$timing_table[
+        rows$unique_timing_key,
+        cols$unique_timing_key
+      ] + 1
       inner_terms <- inner_terms * inner_terms_timing
     }
 
@@ -585,61 +575,18 @@ distance_matrix_constructor <- function(
     inner_terms <- 1
   }
 
+  # apply summary method
+  if (method$summation_method %in% c("sum_of_minima", "double_sum")) {
+    func_name <- paste0("rcpp_", method$summation_method, "_", calc)
+    selected_func <- get(func_name, mode = "function")
 
-
-  # sum term method
-  if (method$summation_method == "sum_of_minima") {
-
-    if (calc == "triangle") {
-      min_sums <- rcpp_sum_of_minima_triangle(
-        length(unique(rows$unique_pattern_key)),
-        rows$unique_pattern_key,
-        inner_terms
-      )
-    } else if (calc == "full") {
-
-      min_sums <- rcpp_sum_of_minima_full(
-        length(unique(rows$unique_pattern_key)),
-        length(unique(cols$unique_pattern_key)),
-        rows$unique_pattern_key,
-        cols$unique_pattern_key,
-        Rfast::transpose(inner_terms)
-      )
-    }
-
-    # normalizing
-    if (method["alpha"] == 0) {
-      distance_matrix <- min_sums
-    } else {
-      distance_matrix <- normalizer * min_sums
-    }
-
-
-  } else if (method$summation_method == "double_sum") {
-
-    if (calc == "triangle") {
-      sum_terms <- rcpp_double_sum_triangle(
-        length(unique(rows$unique_pattern_key)),
-        rows$unique_pattern_key,
-        inner_terms
-      )
-    } else if (calc == "full") {
-      sum_terms <- rcpp_double_sum_full(
-        length(unique(rows$unique_pattern_key)),
-        length(unique(cols$unique_pattern_key)),
-        rows$unique_pattern_key,
-        cols$unique_pattern_key,
-        Rfast::transpose(inner_terms)
-      )
-    }
-
-    # normalizing
-    if (method["alpha"] == 0) {
-      distance_matrix <- sum_terms
-    } else {
-      distance_matrix <- normalizer * sum_terms
-    }
-
+    distance_matrix <- selected_func(
+      length(unique(rows$unique_pattern_key)),
+      length(unique(cols$unique_pattern_key)),
+      rows$unique_pattern_key,
+      cols$unique_pattern_key,
+      inner_terms
+    )
   } else {
     stop(
       paste0(
@@ -649,7 +596,12 @@ distance_matrix_constructor <- function(
     )
   }
 
-  return(distance_matrix)
+  # Normalizing
+  if (method["alpha"] == 0) {
+    return(distance_matrix)
+  } else {
+    return(normalizer * distance_matrix)
+  }
 }
 
 
@@ -734,17 +686,17 @@ hierarchical_clustering <- function(
 
   cluster_names <- paste0(method$clustering, "_k=", k)
 
-  pattern_clusters <- data.frame(stats::cutree(dendogram, k)) %>%
+  pattern_clusters <- data.frame(stats::cutree(dendogram, k)) |>
     dplyr::rename_at(dplyr::vars(tidyselect::everything()), ~cluster_names)
 
 
   if (is.null(members)) {
-    pattern_clusters <- pattern_clusters %>%
-      tibble::rownames_to_column(var = "unique_pattern_key") %>%
+    pattern_clusters <- pattern_clusters |>
+      tibble::rownames_to_column(var = "unique_pattern_key") |>
       dplyr::mutate(unique_pattern_key = as.numeric(.data$unique_pattern_key))
     joiner <- "unique_pattern_key"
   } else {
-    pattern_clusters <- pattern_clusters %>%
+    pattern_clusters <- pattern_clusters |>
       tibble::rownames_to_column(var = names(keys$base_clustering)[1])
     joiner <-  names(keys$base_clustering)[1]
   }
@@ -752,15 +704,15 @@ hierarchical_clustering <- function(
 
   #   ===   ORGANISING RESULTS   =============================================
 
-  cluster_assignment <- keys$key %>%
+  cluster_assignment <- keys$key |>
     dplyr::select(
       ".internal_character_id",
       "unique_pattern_key",
       dplyr::any_of(names(keys$base_clustering)[1])
-    ) %>%
-    dplyr::distinct() %>%
-    dplyr::left_join(pattern_clusters, by = joiner) %>%
-    dplyr::select(".internal_character_id", dplyr::all_of(cluster_names)) %>%
+    ) |>
+    dplyr::distinct() |>
+    dplyr::left_join(pattern_clusters, by = joiner) |>
+    dplyr::select(".internal_character_id", dplyr::all_of(cluster_names)) |>
     dplyr::mutate(
       dplyr::across(
         dplyr::all_of(cluster_names),
